<?php
namespace TecFood\Controllers;

use Zeedhi\Framework\DataSource\DataSet;

class Session {

	private $crudService;
	private $environment;
	private $entityManager;

	public function __construct($crudService, $environment, $entityManager) {
		$this->crudService = $crudService;
		$this->environment = $environment;
		$this->entityManager = $entityManager;
	}

	public function startSession($request, $response) {

		$user = $request->getRow();
		$this->environment->setCdFilial($user['cdfilialselecionada']);
		$this->environment->setNrOrgTrab($user['nrorg']);
		$this->environment->setFiliOper($this->getFiliOper());
		
		$paramgeralDataSet = $this->getParamgeral();
		$paramfilialDataSet = $this->getParamfilial();

		$paramgeral = $paramgeralDataSet->getRows();
		$idutildtproc = isset($paramgeral[0]) && isset($paramgeral[0]["IDUTILDTPROC"]) ? $paramgeral[0]["IDUTILDTPROC"] : 'N';

		$paramfilial = $paramfilialDataSet->getRows();
		$currentDate = date("d/m/Y 00:00:00");
		if (!empty($paramfilial)) {
			$dtprocessa = isset($paramfilial[0]["DTPROCESSA"]) ? $paramfilial[0]["DTPROCESSA"] : $currentDate;
			$dtprocessa = $idutildtproc == 'S' ? $dtprocessa : $currentDate;
			$paramfilial[0]["DTPROCESSA"] = $dtprocessa;
		} else {
			$paramfilial = array();
		}
		$paramfilialDataSet = new DataSet("paramfilial", $paramfilial);
		
		$filialDataSet = self::getCentralCompras();
		
		$response->addDataSet($paramgeralDataSet);
		$response->addDataSet($paramfilialDataSet);
		$response->addDataSet($filialDataSet);
		
	}
	
	private function getFiliOper() {
		$conditions = array(
			array(
				"columnName" => "NRORG",
				"operator" => "=",
				"value" => $this->environment->getNrOrg()
			),
			array(
				"columnName" => "CDOPERADOR",
				"operator" => "=",
				"value" => $this->environment->getCdOperador()
			)
		); 
		$query = "SELECT F.CDFILIAL FROM FILIAL F JOIN FILIOPER FO ON F.CDFILIAL = FO.CDFILIAL WHERE FO.CDOPERADOR = :CDOPERADOR AND F.NRORG = :NRORG ORDER BY FO.CDFILIAL ASC, F.NMFILIAL ASC";
		$connection = $this->entityManager->getConnection();
		$stmt = $connection->prepare($query);
		$params = array(
			'CDOPERADOR' => $this->environment->getCdOperador(),
			'NRORG'      => $this->environment->getNrOrg()
		);
		$stmt->execute($params);
		$unidadesFiliOper = array();
		do {
			$cdfilial = $stmt->fetchColumn();
			if($cdfilial){
				array_push($unidadesFiliOper, $cdfilial);
			}
		} while($cdfilial);
		return $unidadesFiliOper;
    }
	
	private function getCentralCompras() {
		
		$filialLogada = $this->environment->getCdFilial();
		
		if($filialLogada) {
			$filial = $this->getFilial($filialLogada)->getRows();
			$filial[0]['CDFILCENTCMP'] = $filial[0]['CDFILCENTCMP'] ? $filial[0]['CDFILCENTCMP'] : $filialLogada;
		} else {
			$filial = array();
		}
		
		return new DataSet("filial", $filial);
		
	}

	private function getParamgeral() {
		$conditions = array(
			array(
				"columnName" => "NRORG",
				"operator" => "=",
				"value" => $this->environment->getNrOrg()
			)
		);
		return $this->crudService->getFilteredDataSet("paramgeral", $conditions);
	}

	private function getParamfilial() {
		$conditions = array(
			array(
				"columnName" => "NRORG",
				"operator" => "=",
				"value" => $this->environment->getNrOrg()
			),
			array(
				"columnName" => "CDFILIAL",
				"operator" => "=",
				"value" => $this->environment->getCdFilial()
			)
		);
		return $this->crudService->getFilteredDataSet("paramfilial", $conditions);
	}

	private function getFilial($cdfilial) {
		$conditions = array(
			array(
				"columnName" => "NRORG",
				"operator" => "=",
				"value" => $this->environment->getNrOrg()
			),
			array(
				"columnName" => "CDFILIAL",
				"operator" => "=",
				"value" => $cdfilial
			)
		);
		return $this->crudService->getFilteredDataSet("filial", $conditions);
	}
}